/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: AbstractJasmineEventDataExtractor.java 4798 2009-08-07 12:30:47Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.common.util.extractor;

import java.io.IOException;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

import javax.naming.NamingException;

import org.ow2.jasmine.monitoring.common.api.extractor.IJasmineEventDataExtractor;
import org.ow2.jasmine.monitoring.eventswitch.beans.JasmineEventSLBRemote;
import org.ow2.jasmine.monitoring.eventswitch.connectors.EJB3Connector;
import org.ow2.jasmine.event.beans.JasmineEventEB;

public abstract class AbstractJasmineEventDataExtractor extends EJB3Connector<JasmineEventSLBRemote> implements IJasmineEventDataExtractor{

	public JasmineEventEB[] getEvents(final String[] args) throws NamingException, ParseException, IOException {
		ArgumentParser p = new ArgumentParser(args);
        setConfiguration(p.getOptions());
        String format = p.getOption("timeformat");
        if (format != null || "long".equalsIgnoreCase(format)) {
            formatter = new SimpleDateFormat(format);
        }
        int limit;
        try {
            limit=Integer.parseInt(p.getOption("limit"));
        } catch (Exception e) {
        	limit = 1000;
            System.err.println("No limit specified: defaulting to 1000.");
        }

        connect();
        JasmineEventEB[] events = getBean().getEvents(p.getOption("domain"), p.getOption("server"),
                p.getOption("source"), p.getOption("probe"), p.getOption("value"),
                getTime(p.getOption("startTimestamp")), getTime(p.getOption("endTimestamp")), "timestamp", limit);
        disconnect();

        return events;
	}
	
	/**
     * Parses a given time using the formatter, defaults to format "long".
     *
     * @param s  Time to parse, can be null (in that case return is null).
     *
     * @return Parsed time.
     *
     * @throws ParseException  If parsing fails.
     */
	public Date getTime(String s) throws ParseException {
		if (s == null) {
            return null;
        }

        if (formatter == null) {
            return new Date(Long.parseLong(s));
        } else {
            return formatter.parse(s);
        }
	}
	
	/**
     * Date format, null means "long".
     */
    public SimpleDateFormat formatter = null;

}
